@@ -19,10 +19,11 @@ class AttributeDictionary(dict[Any, Any]):
     """
     A dictionary subclass that supports attribute-style access.
 
-    This class extends the functionality of a standard dictionary to allow items to be accessed
-    via attribute-style dot notation in addition to the traditional key-based access. If a dictionary
-    item is accessed and is itself a dictionary, it is automatically wrapped in another `AttributeDictionary`,
-    enabling recursive attribute-style access.
+    This class extends the functionality of a standard dictionary to allow items
+    to be accessed via attribute-style dot notation in addition to the traditional
+    key-based access. If a dictionary item is accessed and is itself a dictionary,
+    it is automatically wrapped in another `AttributeDictionary`, enabling recursive
+    attribute-style access.
     """
 
     def __getattr__(self, key):
@@ -34,4 +35,5 @@ class AttributeDictionary(dict[Any, Any]):
                 f"'{type(self).__name__}' object has no attribute '{key}'"
             ) from err
 
-    __setattr__ = dict.__setitem__
+    def __setattr__(self, name: str, value: Any) -> None:
+        self[name] = value
